@@ -27,34 +27,37 @@ GeomInteractiveErrorbarh <- ggproto(
   default_aes = add_default_interactive_aes(GeomErrorbarh),
   parameters = interactive_geom_parameters,
   draw_key = interactive_geom_draw_key,
+
   draw_panel = function(
     self,
     data,
     panel_params,
     coord,
-    height = NULL,
     lineend = "butt",
+    width = NULL,
+    flipped_aes = FALSE,
     .ipar = IPAR_NAMES
   ) {
-    x = vec_interleave(
-      data$xmax,
+    data <- flip_data(data, flipped_aes)
+    x <- vec_interleave(
+      data$xmin,
       data$xmax,
       NA,
-      data$xmax,
-      data$xmin,
+      data$x,
+      data$x,
       NA,
       data$xmin,
-      data$xmin
+      data$xmax
     )
-    y = vec_interleave(
-      data$ymin,
+    y <- vec_interleave(
+      data$ymax,
       data$ymax,
       NA,
-      data$y,
-      data$y,
+      data$ymax,
+      data$ymin,
       NA,
       data$ymin,
-      data$ymax
+      data$ymin
     )
     z <- data_frame0(
       x = x,
@@ -63,9 +66,10 @@ GeomInteractiveErrorbarh <- ggproto(
       alpha = rep(data$alpha, each = 8),
       linewidth = rep(data$linewidth, each = 8),
       linetype = rep(data$linetype, each = 8),
-      group = rep(1:(nrow(data)), each = 8),
+      group = rep(seq_len(nrow(data)), each = 8),
       .size = nrow(data) * 8
     )
+
     z <- copy_interactive_attrs(data, z, each = 8, ipar = .ipar)
     GeomInteractivePath$draw_panel(
       z,
