@@ -399,13 +399,22 @@ interactive_attr_toxml <- function(x, ids = character(0), rows = NULL) {
     }
     attrName <- switch(a, tooltip = "title", data_id = data_attr, a)
 
-    if (isTRUE("fill_na" %in% x$.interactive_hooks) && anyNA(attrValue) && !is.na(attrValue[1])) {
-      attrValue <- Reduce(f = function(a, b) {
-        newb <- if (is.na(b)) {
-          rev(a)[1]
-        } else b
-        c(a, newb)
-      }, x = attrValue)
+    if (
+      isTRUE("fill_na" %in% x$.interactive_hooks) &&
+        anyNA(attrValue) &&
+        !is.na(attrValue[1])
+    ) {
+      attrValue <- Reduce(
+        f = function(a, b) {
+          newb <- if (is.na(b)) {
+            rev(a)[1]
+          } else {
+            b
+          }
+          c(a, newb)
+        },
+        x = attrValue
+      )
     }
 
     set_attr(
